Chaco Lotka-Volterra Population Model Plot Example
===============================================================================

:download:`lotka_volterra_ui.enaml <../../../examples/chaco/lotka_volterra_ui.enaml>`

:download:`lotka_volterra.py <../../../examples/chaco/lotka_volterra.py>`

.. literalinclude:: ../../../examples/chaco/lotka_volterra_ui.enaml
    :language: python

.. literalinclude:: ../../../examples/chaco/lotka_volterra.py
    :language: python

::

 $ python lotka_volterra.py

.. image:: images/chaco_lotka_volterra.png

